@@ -1,6 +1,6 @@
 try:
     import importlib.metadata as importlib_metadata
-except ModuleNotFoundError:
+except ModuleNotFoundError: # pragma: no cover
     import importlib_metadata
 
 __version__ = importlib_metadata.version(__name__)
